"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PhoneInput = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _reactNativeCountryPickerModal = _interopRequireWildcard(require("react-native-country-picker-modal"));
var _reactNativeMaskInput = _interopRequireDefault(require("react-native-mask-input"));
var _constants = require("./constants.js");
var _styles = _interopRequireDefault(require("./styles.js"));
var _usePhoneInput = require("./usePhoneInput.js");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const isDarkTheme = _reactNative.Appearance.getColorScheme() === 'dark';
const dropDownImage = 'data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAi0lEQVRYR+3WuQ6AIBRE0eHL1T83FBqU5S1szdiY2NyTKcCAzU/Y3AcBXIALcIF0gRPAsehgugDEXnYQrUC88RIgfpuJ+MRrgFmILN4CjEYU4xJgFKIa1wB6Ec24FuBFiHELwIpQxa0ALUId9wAkhCnuBdQQ5ngP4I9wxXsBDyJ9m+8y/g9wAS7ABW4giBshQZji3AAAAABJRU5ErkJggg==';
const PhoneInput = props => {
  const {
    models: {
      countryCode,
      phoneNumber,
      mask,
      inputRef
    },
    actions: {
      handleChangeText,
      onSelect
    },
    forms: {
      modalVisible,
      showModal,
      hideModal
    }
  } = (0, _usePhoneInput.usePhoneInput)(props);
  const {
    theme: {
      enableDarkTheme = isDarkTheme,
      textInputStyle,
      flagButtonStyle,
      containerStyle,
      dropDownImageStyle
    } = {},
    maskInputProps,
    autoFocus,
    hideDropdownIcon,
    renderCustomDropdown,
    countryPickerProps,
    flagProps,
    disabled,
    dropDownImageProps
  } = props;
  const renderFlagButton = (0, _react.useCallback)(() => /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeCountryPickerModal.FlagButton, {
    countryCode: countryCode,
    flagSize: flagProps?.flagSize || _reactNativeCountryPickerModal.DEFAULT_THEME.flagSize,
    placeholder: countryCode,
    ...flagProps
  }), [countryCode, flagProps]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeCountryPickerModal.CountryModalProvider, {
    children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.View, {
      testID: "phone-input-container",
      style: [_styles.default.container, containerStyle],
      children: [/*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.TouchableOpacity, {
        testID: "country-picker-button",
        style: [_styles.default.flagButtonView, flagButtonStyle],
        disabled: disabled,
        onPress: showModal,
        children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeCountryPickerModal.default, {
          onSelect: onSelect,
          withEmoji: true,
          withFilter: true,
          withFlag: true,
          withAlphaFilter: true,
          countryCode: countryCode,
          withCallingCode: true,
          disableNativeModal: disabled,
          visible: modalVisible,
          theme: enableDarkTheme ? _reactNativeCountryPickerModal.DARK_THEME : _reactNativeCountryPickerModal.DEFAULT_THEME,
          renderFlagButton: renderFlagButton,
          excludeCountries: _constants.EXCLUDED_COUNTRIES,
          onClose: hideModal,
          ...countryPickerProps
        }), !hideDropdownIcon && (renderCustomDropdown || /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Image, {
          testID: "dropdown-icon",
          source: {
            uri: dropDownImage
          },
          resizeMode: "contain",
          style: [_styles.default.dropDownImage, dropDownImageStyle],
          ...dropDownImageProps
        }))]
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeMaskInput.default, {
        testID: "phone-input",
        ref: ref => {
          inputRef.current = ref;
        },
        style: [_styles.default.numberText, textInputStyle],
        mask: mask,
        onChangeText: handleChangeText,
        value: phoneNumber,
        editable: !disabled,
        selectionColor: "black",
        keyboardAppearance: enableDarkTheme ? 'dark' : 'default',
        keyboardType: "number-pad",
        autoFocus: autoFocus,
        ...maskInputProps
      })]
    })
  });
};
exports.PhoneInput = PhoneInput;
//# sourceMappingURL=PhoneInput.js.map