"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.usePhoneInput = void 0;
var _react = require("react");
var _constants = require("./constants.js");
var _utils = require("./utils.js");
const usePhoneInput = ({
  defaultValues,
  value,
  onChangeCountry,
  onChangeText,
  isCallingCodeEditable = true
}) => {
  const inputRef = (0, _react.useRef)();
  const [callingCode, setCallingCode] = (0, _react.useState)(defaultValues?.callingCode || '+994');
  const [phoneNumber, setPhoneNumber] = (0, _react.useState)(value || defaultValues?.phoneNumber || '+994');
  const [modalVisible, setModalVisible] = (0, _react.useState)(false);
  const [countryCode, setCountryCode] = (0, _react.useState)(defaultValues?.countryCode || 'AZ');
  const [mask, setMask] = (0, _react.useState)((0, _utils.getFullMaskPhoneNumber)(callingCode, countryCode));
  const showModal = () => setModalVisible(true);
  const hideModal = () => setModalVisible(false);
  const updateCountryOnType = (0, _react.useCallback)(inputText => {
    if (_constants.CALLING_CODE_PER_COUNTRY_CODE?.[inputText]) {
      setCallingCode(inputText);
      const newCountryCode = _constants.CALLING_CODE_PER_COUNTRY_CODE?.[inputText];
      setCountryCode(newCountryCode);
      setMask((0, _utils.getFullMaskPhoneNumber)(inputText, newCountryCode));
    }
  }, []);
  const onSelect = (0, _react.useCallback)(country => {
    const newCallingCode = (0, _utils.ensurePlusPrefix)(country.callingCode[0]);
    setCountryCode(country.cca2);
    setCallingCode(newCallingCode);
    setPhoneNumber(newCallingCode);
    setMask((0, _utils.getFullMaskPhoneNumber)(newCallingCode, country.cca2));
    onChangeCountry?.(country);
  }, [onChangeCountry]);
  const handleChangeText = (0, _react.useCallback)((_masked, unmasked, _obfuscated) => {
    const text = (0, _utils.ensurePlusPrefix)(unmasked);
    if (!isCallingCodeEditable && text.length < callingCode.length) return;
    updateCountryOnType(text);
    setPhoneNumber(text);
    onChangeText?.(text);
  }, [isCallingCodeEditable, callingCode.length, updateCountryOnType, onChangeText]);
  return {
    models: {
      countryCode,
      callingCode,
      phoneNumber,
      mask,
      inputRef
    },
    actions: {
      onSelect,
      handleChangeText,
      setMask
    },
    forms: {
      modalVisible,
      showModal,
      hideModal
    }
  };
};
exports.usePhoneInput = usePhoneInput;
//# sourceMappingURL=usePhoneInput.js.map