"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isValidNumber = exports.getFullPhoneNumber = exports.getFullMaskPhoneNumber = exports.ensurePlusPrefix = void 0;
var _googleLibphonenumber = require("google-libphonenumber");
var _constants = require("./constants.js");
const phoneUtil = _googleLibphonenumber.PhoneNumberUtil.getInstance();
const isValidNumber = (number, countryCode) => {
  try {
    const parsedNumber = phoneUtil.parse(number, countryCode);
    return phoneUtil.isValidNumber(parsedNumber);
  } catch (err) {
    return false;
  }
};
exports.isValidNumber = isValidNumber;
const ensurePlusPrefix = number => {
  if (!number) return '';
  if (number.startsWith('+')) {
    return number;
  }
  return `+${number}`;
};
exports.ensurePlusPrefix = ensurePlusPrefix;
const getFullPhoneNumber = (prefix, phoneNumber) => {
  return `${ensurePlusPrefix(prefix)}${phoneNumber}`;
};
exports.getFullPhoneNumber = getFullPhoneNumber;
const callingCodeToMaskArray = callingCode => callingCode.split('').map(char => char === '+' ? '+' : /\d/);
const getFullMaskPhoneNumber = (callingCode, countryCode) => [...callingCodeToMaskArray(callingCode), ' ', ...(_constants.MASK_PER_COUNTRY[countryCode] || [])];
exports.getFullMaskPhoneNumber = getFullMaskPhoneNumber;
//# sourceMappingURL=utils.js.map