"use strict";

import React, { useCallback } from 'react';
import { Appearance, Image, TouchableOpacity, View } from 'react-native';
import CountryPicker, { CountryModalProvider, DARK_THEME, DEFAULT_THEME, FlagButton } from 'react-native-country-picker-modal';
import MaskInput from 'react-native-mask-input';
import { EXCLUDED_COUNTRIES } from "./constants.js";
import styles from "./styles.js";
import { usePhoneInput } from "./usePhoneInput.js";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const isDarkTheme = Appearance.getColorScheme() === 'dark';
const dropDownImage = 'data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAi0lEQVRYR+3WuQ6AIBRE0eHL1T83FBqU5S1szdiY2NyTKcCAzU/Y3AcBXIALcIF0gRPAsehgugDEXnYQrUC88RIgfpuJ+MRrgFmILN4CjEYU4xJgFKIa1wB6Ec24FuBFiHELwIpQxa0ALUId9wAkhCnuBdQQ5ngP4I9wxXsBDyJ9m+8y/g9wAS7ABW4giBshQZji3AAAAABJRU5ErkJggg==';
export const PhoneInput = props => {
  const {
    models: {
      countryCode,
      phoneNumber,
      mask,
      inputRef
    },
    actions: {
      handleChangeText,
      onSelect
    },
    forms: {
      modalVisible,
      showModal,
      hideModal
    }
  } = usePhoneInput(props);
  const {
    theme: {
      enableDarkTheme = isDarkTheme,
      textInputStyle,
      flagButtonStyle,
      containerStyle,
      dropDownImageStyle
    } = {},
    maskInputProps,
    autoFocus,
    hideDropdownIcon,
    renderCustomDropdown,
    countryPickerProps,
    flagProps,
    disabled,
    dropDownImageProps
  } = props;
  const renderFlagButton = useCallback(() => /*#__PURE__*/_jsx(FlagButton, {
    countryCode: countryCode,
    flagSize: flagProps?.flagSize || DEFAULT_THEME.flagSize,
    placeholder: countryCode,
    ...flagProps
  }), [countryCode, flagProps]);
  return /*#__PURE__*/_jsx(CountryModalProvider, {
    children: /*#__PURE__*/_jsxs(View, {
      testID: "phone-input-container",
      style: [styles.container, containerStyle],
      children: [/*#__PURE__*/_jsxs(TouchableOpacity, {
        testID: "country-picker-button",
        style: [styles.flagButtonView, flagButtonStyle],
        disabled: disabled,
        onPress: showModal,
        children: [/*#__PURE__*/_jsx(CountryPicker, {
          onSelect: onSelect,
          withEmoji: true,
          withFilter: true,
          withFlag: true,
          withAlphaFilter: true,
          countryCode: countryCode,
          withCallingCode: true,
          disableNativeModal: disabled,
          visible: modalVisible,
          theme: enableDarkTheme ? DARK_THEME : DEFAULT_THEME,
          renderFlagButton: renderFlagButton,
          excludeCountries: EXCLUDED_COUNTRIES,
          onClose: hideModal,
          ...countryPickerProps
        }), !hideDropdownIcon && (renderCustomDropdown || /*#__PURE__*/_jsx(Image, {
          testID: "dropdown-icon",
          source: {
            uri: dropDownImage
          },
          resizeMode: "contain",
          style: [styles.dropDownImage, dropDownImageStyle],
          ...dropDownImageProps
        }))]
      }), /*#__PURE__*/_jsx(MaskInput, {
        testID: "phone-input",
        ref: ref => {
          inputRef.current = ref;
        },
        style: [styles.numberText, textInputStyle],
        mask: mask,
        onChangeText: handleChangeText,
        value: phoneNumber,
        editable: !disabled,
        selectionColor: "black",
        keyboardAppearance: enableDarkTheme ? 'dark' : 'default',
        keyboardType: "number-pad",
        autoFocus: autoFocus,
        ...maskInputProps
      })]
    })
  });
};
//# sourceMappingURL=PhoneInput.js.map