"use strict";

import { useCallback, useRef, useState } from 'react';
import { CALLING_CODE_PER_COUNTRY_CODE } from "./constants.js";
import { ensurePlusPrefix, getFullMaskPhoneNumber } from "./utils.js";
export const usePhoneInput = ({
  defaultValues,
  value,
  onChangeCountry,
  onChangeText,
  isCallingCodeEditable = true
}) => {
  const inputRef = useRef();
  const [callingCode, setCallingCode] = useState(defaultValues?.callingCode || '+994');
  const [phoneNumber, setPhoneNumber] = useState(value || defaultValues?.phoneNumber || '+994');
  const [modalVisible, setModalVisible] = useState(false);
  const [countryCode, setCountryCode] = useState(defaultValues?.countryCode || 'AZ');
  const [mask, setMask] = useState(getFullMaskPhoneNumber(callingCode, countryCode));
  const showModal = () => setModalVisible(true);
  const hideModal = () => setModalVisible(false);
  const updateCountryOnType = useCallback(inputText => {
    if (CALLING_CODE_PER_COUNTRY_CODE?.[inputText]) {
      setCallingCode(inputText);
      const newCountryCode = CALLING_CODE_PER_COUNTRY_CODE?.[inputText];
      setCountryCode(newCountryCode);
      setMask(getFullMaskPhoneNumber(inputText, newCountryCode));
    }
  }, []);
  const onSelect = useCallback(country => {
    const newCallingCode = ensurePlusPrefix(country.callingCode[0]);
    setCountryCode(country.cca2);
    setCallingCode(newCallingCode);
    setPhoneNumber(newCallingCode);
    setMask(getFullMaskPhoneNumber(newCallingCode, country.cca2));
    onChangeCountry?.(country);
  }, [onChangeCountry]);
  const handleChangeText = useCallback((_masked, unmasked, _obfuscated) => {
    const text = ensurePlusPrefix(unmasked);
    if (!isCallingCodeEditable && text.length < callingCode.length) return;
    updateCountryOnType(text);
    setPhoneNumber(text);
    onChangeText?.(text);
  }, [isCallingCodeEditable, callingCode.length, updateCountryOnType, onChangeText]);
  return {
    models: {
      countryCode,
      callingCode,
      phoneNumber,
      mask,
      inputRef
    },
    actions: {
      onSelect,
      handleChangeText,
      setMask
    },
    forms: {
      modalVisible,
      showModal,
      hideModal
    }
  };
};
//# sourceMappingURL=usePhoneInput.js.map