"use strict";

import { PhoneNumberUtil } from 'google-libphonenumber';
import { MASK_PER_COUNTRY } from "./constants.js";
const phoneUtil = PhoneNumberUtil.getInstance();
export const isValidNumber = (number, countryCode) => {
  try {
    const parsedNumber = phoneUtil.parse(number, countryCode);
    return phoneUtil.isValidNumber(parsedNumber);
  } catch (err) {
    return false;
  }
};
export const ensurePlusPrefix = number => {
  if (!number) return '';
  if (number.startsWith('+')) {
    return number;
  }
  return `+${number}`;
};
export const getFullPhoneNumber = (prefix, phoneNumber) => {
  return `${ensurePlusPrefix(prefix)}${phoneNumber}`;
};
const callingCodeToMaskArray = callingCode => callingCode.split('').map(char => char === '+' ? '+' : /\d/);
export const getFullMaskPhoneNumber = (callingCode, countryCode) => [...callingCodeToMaskArray(callingCode), ' ', ...(MASK_PER_COUNTRY[countryCode] || [])];
//# sourceMappingURL=utils.js.map